@@ -416,7 +416,12 @@ GdkPixmap * copy_pixmap(Shiny_switcher *shinyswitcher, GdkPixmap * src)
 {
   GdkPixmap * copy;
   int  w, h;
+  g_return_val_if_fail(src,NULL);
   gdk_drawable_get_size(src, &w, &h);
+  if (!w || !h)
+  {
+    return NULL;
+  }
   copy = gdk_pixmap_new(src, w, h, 32);   /* FIXME */
   gdk_draw_drawable(copy, shinyswitcher->gdkgc, src, 0, 0, 0, 0, -1, -1);
   return copy;
@@ -828,9 +833,11 @@ void create_containers(Shiny_switcher *shinyswitcher)
       }
 
       copy = copy_pixmap(shinyswitcher, copy);
-
-      gtk_container_add(ev, gtk_image_new_from_pixmap(copy, NULL));
-      g_object_unref(copy);
+      if (copy)
+      {
+        gtk_container_add(ev, gtk_image_new_from_pixmap(copy, NULL));
+        g_object_unref(copy);
+      }
     }
     else
     {
@@ -847,9 +854,11 @@ void create_containers(Shiny_switcher *shinyswitcher)
       }
 
       copy = copy_pixmap(shinyswitcher, copy);
-
-      gtk_container_add(ev, gtk_image_new_from_pixmap(copy, NULL));
-      g_object_unref(copy);
+      if (copy)
+      {
+        gtk_container_add(ev, gtk_image_new_from_pixmap(copy, NULL));
+        g_object_unref(copy);
+      }
     }
 
     gtk_fixed_put(GTK_CONTAINER(shinyswitcher->mini_wins[win_num]), ev, 0, 0);
@@ -1571,6 +1580,10 @@ void render_windows_to_wallpaper(Shiny_switcher *shinyswitcher,  WnckWorkspace *
             GdkPixmap *pixmap;
             gtk_image_get_pixmap(gtk_bin_get_child(ws->wallpaper_ev), &pixmap, NULL);
             cairo_t * destcr = gdk_cairo_create(pixmap);
+            if (!destcr)
+            {
+              continue;
+            }
             cairo_set_operator(destcr, CAIRO_OPERATOR_CLEAR);
             cairo_fill(destcr);
 
@@ -2066,6 +2079,8 @@ applet_new(AwnApplet *applet, gint orient, int width, int height)
   shinyswitcher->align  = NULL;
   shinyswitcher->config = NULL;
   shinyswitcher->applet = applet;
+  shinyswitcher->wallpaper_active = NULL;
+  shinyswitcher->wallpaper_inactive = NULL;
   shinyswitcher->ws_lookup_ev = g_tree_new(_cmp_ptrs);
 
   /* doing this as a tree right now..  cause it's easy and I think I'll need a complex data structure eventually. */
